@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2026 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -76,4 +76,9 @@
 #define SDL_DYNAMIC_API 1
 #endif
 
+#if SDL_DYNAMIC_API
+typedef void (*SDLDynamicAPILogAtStartupFunc) (const char *);
+void SDL_DynamicAPISetLogAtStartup(SDLDynamicAPILogAtStartupFunc func);
+#endif
+
 #endif
