@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2026 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -36,7 +36,7 @@
 
 SDL2_PRIVATE void SDL2Compat_NSLog(const char *prefix, const char *text)
 {
-    @autoreleasepool {
+    NSAutoreleasePool *pool = [[NSAutoreleasePool alloc] init]; {
         NSString *nsText = [NSString stringWithUTF8String:text];
         if (prefix && *prefix) {
             NSString *nsPrefix = [NSString stringWithUTF8String:prefix];
@@ -45,6 +45,7 @@ SDL2_PRIVATE void SDL2Compat_NSLog(const char *prefix, const char *text)
             NSLog(@"%@", nsText);
         }
     }
+    [pool drain];
 }
 
 SDL2_PRIVATE void error_dialog(const char *errorMsg)
